pub async fn create_database(database_url: &str) -> Result<bool, TypedError>Expand description
Create database if it does not already exist. Returns true if a new
database was created, false if it was already present.
pub async fn create_database(database_url: &str) -> Result<bool, TypedError>Create database if it does not already exist. Returns true if a new
database was created, false if it was already present.